package com.qianhe.mapper;

import java.util.List;
import com.qianhe.domain.SjZdsc;

/**
 * 基层三册Mapper接口
 * 
 * @author qianhe
 * @date 2025-08-04
 */
public interface SjZdscMapper 
{
    /**
     * 查询基层三册
     * 
     * @param id 基层三册主键
     * @return 基层三册
     */
    public SjZdsc selectSjZdscById(Long id);

    /**
     * 查询基层三册列表
     * 
     * @param sjZdsc 基层三册
     * @return 基层三册集合
     */
    public List<SjZdsc> selectSjZdscList(SjZdsc sjZdsc);

    /**
     * 新增基层三册
     * 
     * @param sjZdsc 基层三册
     * @return 结果
     */
    public int insertSjZdsc(SjZdsc sjZdsc);

    /**
     * 修改基层三册
     * 
     * @param sjZdsc 基层三册
     * @return 结果
     */
    public int updateSjZdsc(SjZdsc sjZdsc);
    public int plxg(SjZdsc sjZdsc);

    /**
     * 删除基层三册
     * 
     * @param id 基层三册主键
     * @return 结果
     */
    public int deleteSjZdscById(Long id);

    /**
     * 批量删除基层三册
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjZdscByIds(Long[] ids);
}
